"use strict";

/* eslint-disable no-console */

import transform from 'css-to-react-native';
import React, { useMemo } from 'react';
import { Platform, ScrollView, StyleSheet, Text, View } from 'react-native';
import { useSyntaxHighlighter } from '../../hooks/useSyntaxHighlighter';
import { jsx as _jsx } from "react/jsx-runtime";
const monospaceFont = Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace'
});
const DEBUG = true;
function cleanStyle(style) {
  const filtered = Object.entries(style).filter(([_key, value]) => value != null).map(([key, value]) => [key, value]);
  DEBUG && console.log('Cleaning style:', style, 'Filtered:', filtered);
  return transform(filtered);
}
const SyntaxHighlighter = ({
  text,
  language,
  languageId,
  theme,
  fontSize = 14,
  scrollViewProps,
  textStyle,
  containerStyle
}) => {
  DEBUG && console.log('Rendering with theme:', theme?.tokenColors?.length);
  const {
    tokens
  } = useSyntaxHighlighter({
    text,
    language,
    languageId: languageId || String(language),
    theme
  });
  const baseStyles = useMemo(() => {
    const styles = {
      scrollView: {
        flex: 1,
        minHeight: 20
      },
      codeContainer: {
        padding: 16,
        minWidth: '100%',
        backgroundColor: theme.colors?.['editor.background'] || '#1e1e1e'
      },
      lineContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap'
      },
      token: {
        fontFamily: monospaceFont,
        fontSize: 14,
        color: theme.colors?.['editor.foreground'] || '#d4d4d4'
      }
    };
    return StyleSheet.create(styles);
  }, [theme]);
  const renderToken = (token, rowIndex, tokenIndex) => {
    const tokenStyle = token.color ? cleanStyle({
      color: token.color,
      fontStyle: token.fontStyle ? 'italic' : 'normal',
      fontWeight: token.fontStyle ? 'bold' : 'normal'
    }) : undefined;
    return /*#__PURE__*/_jsx(Text, {
      style: [baseStyles.token, tokenStyle, textStyle, {
        fontSize
      }],
      children: token.content
    }, `${rowIndex}-${tokenIndex}`);
  };
  return /*#__PURE__*/_jsx(ScrollView, {
    horizontal: true,
    ...scrollViewProps,
    style: [baseStyles.scrollView, scrollViewProps?.style],
    contentContainerStyle: [baseStyles.codeContainer, scrollViewProps?.contentContainerStyle, containerStyle],
    children: /*#__PURE__*/_jsx(View, {
      onStartShouldSetResponder: () => true,
      children: tokens.map((line, rowIndex) => /*#__PURE__*/_jsx(View, {
        style: baseStyles.lineContainer,
        children: line.map((token, tokenIndex) => renderToken(token, rowIndex, tokenIndex))
      }, rowIndex))
    })
  });
};
export default SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map